@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2015-03-18'; # DATE
-our $VERSION = '0.50'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.51'; # VERSION
 
 use 5.010001;
 use strict;
@@ -163,7 +163,7 @@ _
         },
         array1 => {
             summary => 'Positional, greedy, and plural',
-            'summary.alt.numnoun.singular' => 'Positional, greedy, and singular',
+            'summary.alt.plurality.singular' => 'Positional, greedy, and singular',
             schema => ['array*', of => 'str*'],
             req => 1,
             pos => 1,
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.50 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-03-18.
+This document describes version 0.51 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-04-02.
 
 =head1 DESCRIPTION
 
